pm4py.algo.discovery.alpha.variants package
===========================================

Submodules
----------

pm4py.algo.discovery.alpha.variants.classic module
--------------------------------------------------

.. automodule:: pm4py.algo.discovery.alpha.variants.classic
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.alpha.variants.plus module
-----------------------------------------------

.. automodule:: pm4py.algo.discovery.alpha.variants.plus
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.alpha.variants
   :members:
   :undoc-members:
   :show-inheritance:
